Package: ggpattern
Type: Package
Title: 'ggplot2' Pattern Geoms
Version: 1.3.1
Authors@R: c(person("Mike", "FC", role = "aut"),
             person("Trevor L.", "Davis", role = c("aut", "cre"),
                    email = "trevor.l.davis@gmail.com",
                    comment = c(ORCID = "0000-0001-6341-4639")),
             person("ggplot2 authors", role = "aut"))
Description: Provides 'ggplot2' geoms filled with various patterns.  Includes a patterned version of every 'ggplot2' geom that has a region that can be filled with a pattern.  Provides a suite of 'ggplot2' aesthetics and scales for controlling pattern appearances.  Supports over a dozen builtin patterns (every pattern implemented by 'gridpattern') as well as allowing custom user-defined patterns.
URL: https://github.com/trevorld/ggpattern,
        https://trevorldavis.com/R/ggpattern/
BugReports: https://github.com/trevorld/ggpattern/issues
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 4.1)
Imports: cli, ggplot2 (>= 4.0.2), glue, grid, gridpattern (>= 1.2.2),
        lifecycle, rlang (>= 1.1.3), scales, vctrs
Suggests: ambient, dplyr, gganimate, knitr (>= 1.47), magick, mapproj,
        maps, png, ragg (>= 1.2.0), readr, rmarkdown (>= 2.27), sf (>=
        0.7-3), svglite (>= 2.1.3), testthat (>= 2.1.0), vdiffr (>=
        1.0.6)
VignetteBuilder: knitr, ragg, rmarkdown
Collate: 'a-geom-docs.R' 'aaa-ggplot2-compat-plyr.R'
        'aaa-ggplot2-ggplot-global.R' 'aaa-ggplot2-performance.R'
        'aaa-ggplot2-scale-manual.R' 'aaa-ggplot2-utilities-grid.R'
        'aaa-ggplot2-utilities.R' 'geom-.R' 'geom-rect.R' 'geom-bar.R'
        'geom-tile.R' 'geom-bin2d.R' 'geom-boxplot.R' 'geom-col.R'
        'geom-crossbar.R' 'geom-ribbon.R' 'geom-density.R'
        'geom-histogram.R' 'geom-polygon.R' 'geom-map.R' 'geom-sf.R'
        'geom-violin.R' 'ggpattern-defunct.R' 'ggpattern-deprecated.R'
        'ggpattern-package.R' 'pattern.R' 'polygon_df.R'
        'scale-pattern-alpha.R' 'scale-pattern-auto.R'
        'scale-pattern-brewer.R' 'scale-pattern-colour.R'
        'scale-pattern-gradient.R' 'scale-pattern-grey.R'
        'scale-pattern-hue.R' 'scale-pattern-linetype.R'
        'scale-pattern-shape.R' 'scale-pattern-size.R'
        'scale-pattern-viridis.R' 'scale-pattern.R' 'zxx.R' 'zzz.R'
NeedsCompilation: no
Packaged: 2026-03-06 07:04:21 UTC; trevorld
Author: Mike FC [aut],
  Trevor L. Davis [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6341-4639>),
  ggplot2 authors [aut]
Maintainer: Trevor L. Davis <trevor.l.davis@gmail.com>
Repository: CRAN
Date/Publication: 2026-03-07 07:50:07 UTC
Built: R 4.6.0; ; 2026-04-26 13:15:40 UTC; unix
