# Generated by roxygen2: do not edit by hand

export(GeomAreaPattern)
export(GeomBarPattern)
export(GeomBin2dPattern)
export(GeomBoxplotPattern)
export(GeomColPattern)
export(GeomCrossbarPattern)
export(GeomDensityPattern)
export(GeomMapPattern)
export(GeomPolygonPattern)
export(GeomRectPattern)
export(GeomRibbonPattern)
export(GeomSfPattern)
export(GeomTilePattern)
export(GeomViolinPattern)
export(create_polygon_df)
export(draw_key_boxplot_pattern)
export(draw_key_crossbar_pattern)
export(draw_key_polygon_pattern)
export(geom_area_pattern)
export(geom_bar_pattern)
export(geom_bin2d_pattern)
export(geom_bin_2d_pattern)
export(geom_boxplot_pattern)
export(geom_col_pattern)
export(geom_crossbar_pattern)
export(geom_density_pattern)
export(geom_histogram_pattern)
export(geom_map_pattern)
export(geom_polygon_pattern)
export(geom_rect_pattern)
export(geom_ribbon_pattern)
export(geom_sf_pattern)
export(geom_tile_pattern)
export(geom_violin_pattern)
export(is_polygon_df)
export(scale_pattern_alpha)
export(scale_pattern_alpha_continuous)
export(scale_pattern_alpha_discrete)
export(scale_pattern_alpha_identity)
export(scale_pattern_alpha_manual)
export(scale_pattern_alpha_ordinal)
export(scale_pattern_angle_continuous)
export(scale_pattern_angle_discrete)
export(scale_pattern_angle_identity)
export(scale_pattern_angle_manual)
export(scale_pattern_aspect_ratio_continuous)
export(scale_pattern_aspect_ratio_discrete)
export(scale_pattern_aspect_ratio_identity)
export(scale_pattern_aspect_ratio_manual)
export(scale_pattern_color_brewer)
export(scale_pattern_color_continuous)
export(scale_pattern_color_discrete)
export(scale_pattern_color_distiller)
export(scale_pattern_color_gradient)
export(scale_pattern_color_gradient2)
export(scale_pattern_color_gradientn)
export(scale_pattern_color_grey)
export(scale_pattern_color_hue)
export(scale_pattern_color_identity)
export(scale_pattern_color_manual)
export(scale_pattern_color_ordinal)
export(scale_pattern_color_viridis_c)
export(scale_pattern_color_viridis_d)
export(scale_pattern_colour_brewer)
export(scale_pattern_colour_continuous)
export(scale_pattern_colour_discrete)
export(scale_pattern_colour_distiller)
export(scale_pattern_colour_gradient)
export(scale_pattern_colour_gradient2)
export(scale_pattern_colour_gradientn)
export(scale_pattern_colour_grey)
export(scale_pattern_colour_hue)
export(scale_pattern_colour_identity)
export(scale_pattern_colour_manual)
export(scale_pattern_colour_ordinal)
export(scale_pattern_colour_viridis_c)
export(scale_pattern_colour_viridis_d)
export(scale_pattern_continuous)
export(scale_pattern_density_continuous)
export(scale_pattern_density_discrete)
export(scale_pattern_density_identity)
export(scale_pattern_density_manual)
export(scale_pattern_discrete)
export(scale_pattern_filename_continuous)
export(scale_pattern_filename_discrete)
export(scale_pattern_filename_identity)
export(scale_pattern_filename_manual)
export(scale_pattern_fill2_brewer)
export(scale_pattern_fill2_continuous)
export(scale_pattern_fill2_discrete)
export(scale_pattern_fill2_distiller)
export(scale_pattern_fill2_gradient)
export(scale_pattern_fill2_gradient2)
export(scale_pattern_fill2_gradientn)
export(scale_pattern_fill2_grey)
export(scale_pattern_fill2_hue)
export(scale_pattern_fill2_identity)
export(scale_pattern_fill2_manual)
export(scale_pattern_fill2_ordinal)
export(scale_pattern_fill2_viridis_c)
export(scale_pattern_fill2_viridis_d)
export(scale_pattern_fill_brewer)
export(scale_pattern_fill_continuous)
export(scale_pattern_fill_discrete)
export(scale_pattern_fill_distiller)
export(scale_pattern_fill_gradient)
export(scale_pattern_fill_gradient2)
export(scale_pattern_fill_gradientn)
export(scale_pattern_fill_grey)
export(scale_pattern_fill_hue)
export(scale_pattern_fill_identity)
export(scale_pattern_fill_manual)
export(scale_pattern_fill_ordinal)
export(scale_pattern_fill_viridis_c)
export(scale_pattern_fill_viridis_d)
export(scale_pattern_filter_continuous)
export(scale_pattern_filter_discrete)
export(scale_pattern_filter_identity)
export(scale_pattern_filter_manual)
export(scale_pattern_frequency_continuous)
export(scale_pattern_frequency_discrete)
export(scale_pattern_frequency_identity)
export(scale_pattern_frequency_manual)
export(scale_pattern_gravity_continuous)
export(scale_pattern_gravity_discrete)
export(scale_pattern_gravity_identity)
export(scale_pattern_gravity_manual)
export(scale_pattern_grid_continuous)
export(scale_pattern_grid_discrete)
export(scale_pattern_grid_identity)
export(scale_pattern_grid_manual)
export(scale_pattern_identity)
export(scale_pattern_key_scale_factor_continuous)
export(scale_pattern_key_scale_factor_discrete)
export(scale_pattern_key_scale_factor_identity)
export(scale_pattern_key_scale_factor_manual)
export(scale_pattern_linetype)
export(scale_pattern_linetype_continuous)
export(scale_pattern_linetype_discrete)
export(scale_pattern_linetype_identity)
export(scale_pattern_linetype_manual)
export(scale_pattern_manual)
export(scale_pattern_orientation_continuous)
export(scale_pattern_orientation_discrete)
export(scale_pattern_orientation_identity)
export(scale_pattern_orientation_manual)
export(scale_pattern_phase_continuous)
export(scale_pattern_phase_discrete)
export(scale_pattern_phase_identity)
export(scale_pattern_phase_manual)
export(scale_pattern_res_continuous)
export(scale_pattern_res_discrete)
export(scale_pattern_res_identity)
export(scale_pattern_res_manual)
export(scale_pattern_rot_continuous)
export(scale_pattern_rot_discrete)
export(scale_pattern_rot_identity)
export(scale_pattern_rot_manual)
export(scale_pattern_scale_continuous)
export(scale_pattern_scale_discrete)
export(scale_pattern_scale_identity)
export(scale_pattern_scale_manual)
export(scale_pattern_shape)
export(scale_pattern_shape_continuous)
export(scale_pattern_shape_discrete)
export(scale_pattern_shape_identity)
export(scale_pattern_shape_manual)
export(scale_pattern_shape_ordinal)
export(scale_pattern_size)
export(scale_pattern_size_continuous)
export(scale_pattern_size_discrete)
export(scale_pattern_size_identity)
export(scale_pattern_size_manual)
export(scale_pattern_size_ordinal)
export(scale_pattern_spacing_continuous)
export(scale_pattern_spacing_discrete)
export(scale_pattern_spacing_identity)
export(scale_pattern_spacing_manual)
export(scale_pattern_subtype_continuous)
export(scale_pattern_subtype_discrete)
export(scale_pattern_subtype_identity)
export(scale_pattern_subtype_manual)
export(scale_pattern_type_continuous)
export(scale_pattern_type_discrete)
export(scale_pattern_type_identity)
export(scale_pattern_type_manual)
export(scale_pattern_units_continuous)
export(scale_pattern_units_discrete)
export(scale_pattern_units_identity)
export(scale_pattern_units_manual)
export(scale_pattern_xoffset_continuous)
export(scale_pattern_xoffset_discrete)
export(scale_pattern_xoffset_identity)
export(scale_pattern_xoffset_manual)
export(scale_pattern_yoffset_continuous)
export(scale_pattern_yoffset_discrete)
export(scale_pattern_yoffset_identity)
export(scale_pattern_yoffset_manual)
import(ggplot2)
import(glue)
import(grid)
import(rlang)
import(scales)
import(vctrs)
importFrom(grDevices,col2rgb)
importFrom(grDevices,dev.off)
importFrom(grDevices,png)
importFrom(grDevices,rgb)
importFrom(lifecycle,deprecate_soft)
importFrom(lifecycle,deprecated)
importFrom(stats,setNames)
importFrom(utils,head)
importFrom(utils,tail)
