# Default scales -------------------------------------------------------------

#' @export
#' @rdname scale_pattern_colour_hue
#' @usage NULL
scale_pattern_colour_discrete <- scale_pattern_colour_hue

#' @export
#' @rdname scale_pattern_colour_viridis_d
#' @usage NULL
scale_pattern_colour_ordinal <- scale_pattern_colour_viridis_d

#' @export
#' @rdname scale_pattern_colour_viridis_d
#' @usage NULL
scale_pattern_color_ordinal <- scale_pattern_colour_ordinal


# #' @export
# #' @rdname scale_pattern_colour_gradient
# #' @usage NULL
# scale_pattern_color_datetime <- scale_pattern_colour_datetime


# #' @export
# #' @rdname scale_pattern_colour_gradient
# #' @usage NULL
# scale_pattern_color_date <- scale_pattern_colour_date

#' @export
#' @rdname scale_pattern_colour_hue
#' @usage NULL
scale_pattern_fill_discrete <- scale_pattern_fill_hue

#' @export
#' @rdname scale_pattern_colour_hue
#' @usage NULL
scale_pattern_fill2_discrete <- scale_pattern_fill2_hue

#' @export
#' @rdname scale_pattern_colour_viridis_d
#' @usage NULL
scale_pattern_fill_ordinal <- scale_pattern_fill_viridis_d

#' @export
#' @rdname scale_pattern_colour_viridis_d
#' @usage NULL
scale_pattern_fill2_ordinal <- scale_pattern_fill2_viridis_d



# British to American spellings ----------------------------------------------

#' @export
#' @rdname scale_pattern_colour_brewer
#' @usage NULL
scale_pattern_color_brewer <- scale_pattern_colour_brewer

#' @export
#' @rdname scale_pattern_colour_brewer
#' @usage NULL
scale_pattern_color_distiller <- scale_pattern_colour_distiller

# #' @export
# #' @rdname scale_pattern_brewer
# #' @usage NULL
# scale_pattern_color_fermenter <- scale_pattern_colour_fermenter

#' @export
#' @rdname scale_pattern_colour_continuous
#' @usage NULL
scale_pattern_color_continuous <- scale_pattern_colour_continuous

# #' @export
# #' @rdname scale_pattern_colour_continuous
# #' @usage NULL
# scale_pattern_color_binned <- scale_pattern_colour_binned

#' @export
#' @rdname scale_pattern_colour_hue
#' @usage NULL
scale_pattern_color_discrete <- scale_pattern_colour_hue

#' @export
#' @rdname scale_pattern_colour_gradient
#' @usage NULL
scale_pattern_color_gradient <- scale_pattern_colour_gradient

#' @export
#' @rdname scale_pattern_colour_gradient
#' @usage NULL
scale_pattern_color_gradient2 <- scale_pattern_colour_gradient2

#' @export
#' @rdname scale_pattern_colour_gradient
#' @usage NULL
scale_pattern_color_gradientn <- scale_pattern_colour_gradientn

# #' @export
# #' @rdname scale_pattern_steps
# #' @usage NULL
# scale_pattern_color_steps <- scale_pattern_colour_steps

# #' @export
# #' @rdname scale_pattern_steps
# #' @usage NULL
# scale_pattern_color_steps2 <- scale_pattern_colour_steps2

# #' @export
# #' @rdname scale_pattern_steps
# #' @usage NULL
# scale_pattern_color_stepsn <- scale_pattern_colour_stepsn

#' @export
#' @rdname scale_pattern_colour_grey
#' @usage NULL
scale_pattern_color_grey <- scale_pattern_colour_grey

#' @export
#' @rdname scale_pattern_colour_hue
#' @usage NULL
scale_pattern_color_hue <- scale_pattern_colour_hue

#' @export
#' @rdname scale_pattern_identity
#' @usage NULL
scale_pattern_color_identity <- scale_pattern_colour_identity

#' @export
#' @rdname scale_pattern_manual
#' @usage NULL
scale_pattern_color_manual <- scale_pattern_colour_manual

#' @export
#' @rdname scale_pattern_colour_viridis_d
#' @usage NULL
scale_pattern_color_viridis_d <- scale_pattern_colour_viridis_d

#' @export
#' @rdname scale_pattern_colour_viridis_d
#' @usage NULL
scale_pattern_color_viridis_c <- scale_pattern_colour_viridis_c
