#' Defunct data/functions
#'
#' These data/functions are Defunct in this release of ggpattern.
#' \enumerate{
#' \item{For `magick_filter_names` use `magick::filter_types()` instead.}
#' \item{For `magick_gravity_names` use `magick::gravity_types()` instead.}
#' \item{For `magick_pattern_intensity_names` use `gridpattern::names_magick_intensity`.}
#' \item{For `magick_pattern_names` use `gridpattern::names_magick`.}
#' \item{For `magick_pattern_stripe_names` use `gridpattern::names_magick_stripe`.}
#' \item{For `placeholder_names` use `gridpattern::names_placeholder`.}
#' }
#' @param ... Ignored
#' @aliases magick_filter_names magick_gravity_names magick_pattern_intensity_names magick_pattern_names magick_pattern_stripe_names placeholder_names
#' @name ggpattern-defunct
NULL

#' @rdname ggpattern-defunct
calculate_bbox_polygon_df <- function(...) {
  .Defunct(msg = 'calculate_bbox_polygon_df() is defunct')
}

#' @rdname ggpattern-defunct
convert_img_to_array <- function(...) {
  .Defunct(msg = 'convert_img_to_array() is defunct')
}

#' @rdname ggpattern-defunct
convert_polygon_df_to_alpha_channel <- function(...) {
  .Defunct(msg = 'convert_polygon_df_to_alpha_channel() is defunct')
}

#' @rdname ggpattern-defunct
convert_polygon_df_to_polygon_grob <- function(...) {
  .Defunct(msg = 'convert_polygon_df_to_polygon_grob() is defunct')
}

#' @rdname ggpattern-defunct
convert_polygon_df_to_polygon_sf <- function(...) {
  .Defunct(msg = 'convert_polygon_df_to_polygon_sf() is defunct')
}

#' @rdname ggpattern-defunct
convert_polygon_sf_to_polygon_df <- function(...) {
  .Defunct(msg = 'convert_polygon_sf_to_polygon_df() is defunct')
}

#' @rdname ggpattern-defunct
create_gradient_img <- function(...) {
  .Defunct(msg = 'create_gradient_img() is defunct')
}

#' @rdname ggpattern-defunct
fetch_placeholder_img <- function(...) {
  .Defunct(msg = 'fetch_placeholder_img() is defunct')
}

#' @rdname ggpattern-defunct
fill_area_with_img <- function(...) {
  .Defunct(msg = 'fill_area_with_img() is defunct')
}

#' @rdname ggpattern-defunct
rotate_polygon_df <- function(...) {
  .Defunct(msg = 'rotate_polygon_df() is defunct')
}
