---
name: Bug report
about: File a bug report
title: "[BUG]"
labels: ''
assignees: ''

---

**Bug description**

Please enter here a high-level description of your bug.

**Minimal, reproducible example**

Please enter here a [minimal, reproducible example](https://stackoverflow.com/questions/5963269/how-to-make-a-great-r-reproducible-example) of your bug.  Thanks!

```r
# R code for minimal, reproducible example goes here
```

**Session info**

Please enter here the results of `xfun::session_info("ggpattern")`

```
xfun::session_info("ggpattern") output goes here
```
